==> openfetion_1.6.1-1.tar.gz: openfetion-1.6.1/include/fx_login.h <==
/***************************************************************************
 *   Copyright (C) 2010 by lwp                                             *
 *   levin108@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FX_LOGIN_H
#define FX_LOGIN_H
enum
{
	L_NO_COL = 0 ,
	L_PWD_COL ,
	L_STATE_COL ,
	L_LAST_COL ,
	USER_COLS_NUM
};
extern FxLogin* fx_login_new();

extern void fx_login_free(FxLogin* fxlogin);

extern void fx_login_initialize(FxMain* fxmain);

extern GtkTreeModel* fx_login_create_state_model();

extern GtkTreeModel* fx_login_create_user_model(Config* config);

extern void fx_login_set_last_login_user(FxLogin* fxlogin);

extern void fx_login_set_last_login_state(FxLogin* fxlogin , StateType state);
/* signal function */

extern void* fx_login_thread_func(void* data);

extern void fx_login_action_func(GtkWidget* widget , gpointer data);

extern void fx_login_user_change_func(GtkWidget* widget , gpointer data);

extern gboolean fx_login_proxy_button_func(GtkWidget *widget , GdkEventButton *event , gpointer data);

#endif

==> openfetion_1.8-1.tar.gz: openfetion-1.8/include/fx_login.h <==
/***************************************************************************
 *   Copyright (C) 2010 by lwp                                             *
 *   levin108@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FX_LOGIN_H
#define FX_LOGIN_H
enum
{
	L_NO_COL = 0 ,
	L_PWD_COL ,
	L_STATE_COL ,
	L_LAST_COL ,
	USER_COLS_NUM
};
extern FxLogin* fx_login_new();

extern void fx_login_free(FxLogin* fxlogin);

extern void fx_login_initialize(FxMain* fxmain);

extern GtkTreeModel* fx_login_create_state_model();

extern GtkTreeModel* fx_login_create_user_model(Config* config);

extern void fx_login_set_last_login_user(FxLogin* fxlogin);

extern void fx_login_set_last_login_state(FxLogin* fxlogin , StateType state);
/* signal function */

extern void* fx_login_thread_func(void* data);

extern void fx_login_action_func(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_login_user_change_func(GtkWidget* widget , gpointer data);

extern gboolean fx_login_proxy_button_func(GtkWidget *UNUSED(widget)
		, GdkEventButton *event , gpointer data);

#endif
